@@ -1,14 +1,13 @@
 from .reader import Reader
 from .writer import Writer
 from .text_style import TextStyle
-from .dither_type import DitherType
 from multiprocessing import Process
 from typing import Optional, Tuple
 import os
 from .utils import Utils
 import subprocess
 
-__version__ = "2.5.1"
+__version__ = "2.8.0"
 
 
 class FileTypeError(Exception):
@@ -24,15 +23,15 @@ def __get_reader_writer(
         output: Optional[str] = None,
         width: Optional[int] = None,
         fps_reduction: int = 1,
-        quality: bool = False,
-        dither: bool = False,
+        low_quality: bool = False,
+        disable_dither: bool = False,
         shit_optimize: bool = False,
         text: str = "",
         text_style: TextStyle = TextStyle.TOP,
         progress_bar: bool = False
 ) -> Tuple[Reader, Writer]:
-    reader = Reader(filename, output, width, fps_reduction, dither, shit_optimize, text, text_style, progress_bar)
-    writer = Writer(filename, reader.frames, reader.resolution, output, quality, fps_reduction, dither, shit_optimize,
+    reader = Reader(filename, output, width, fps_reduction, disable_dither, shit_optimize, text, text_style, progress_bar)
+    writer = Writer(filename, reader.frames, reader.resolution, output, low_quality, fps_reduction, disable_dither, shit_optimize,
                     progress_bar)
     return reader, writer
 
@@ -42,8 +41,8 @@ def video2video(
         output: Optional[str] = None,
         width: Optional[int] = None,
         fps_reduction: int = 1,
-        quality: bool = False,
-        dither: bool = False,
+        low_quality: bool = False,
+        disable_dither: bool = False,
         shit_optimize: bool = False,
         text: str = "",
         text_style: TextStyle = TextStyle.TOP,
@@ -52,7 +51,7 @@ def video2video(
     if not os.path.exists(filename):
         raise FileDoesNotExistError(f"File '{filename}' does not exist.")
 
-    reader, writer = __get_reader_writer(filename, output, width, fps_reduction, quality, dither, shit_optimize, text,
+    reader, writer = __get_reader_writer(filename, output, width, fps_reduction, low_quality, disable_dither, shit_optimize, text,
                                          text_style, progress_bar)
 
     try:
@@ -69,14 +68,14 @@ def gif2gif(
         output: Optional[str] = None,
         width: Optional[int] = None,
         fps_reduction: int = 1,
-        quality: bool = False,
-        dither: bool = False,
+        low_quality: bool = False,
+        disable_dither: bool = False,
         shit_optimize: bool = False,
         text: str = "",
         text_style: TextStyle = TextStyle.TOP,
         progress_bar: bool = False
 ) -> None:
-    video2gif(filename, output, width, fps_reduction, quality, dither, shit_optimize, False, text, text_style,
+    video2gif(filename, output, width, fps_reduction, low_quality, disable_dither, shit_optimize, False, text, text_style,
               progress_bar)
 
 
@@ -85,8 +84,8 @@ def video2gif(
         output: Optional[str] = None,
         width: Optional[int] = None,
         fps_reduction: int = 1,
-        quality: bool = False,
-        dither: bool = False,
+        low_quality: bool = False,
+        disable_dither: bool = False,
         shit_optimize: bool = False,
         is_ffmpeg: bool = False,
         text: str = "",
@@ -96,21 +95,25 @@ def video2gif(
     if is_ffmpeg:
         if not output:
             output = Utils.get_output_name(filename)
-        video2video(filename, "temp", width, fps_reduction, quality, False, shit_optimize, text,
+
+        video2video(filename, "temp", width, fps_reduction, low_quality, True, shit_optimize, text,
                     text_style, progress_bar)
-        dither_type = DitherType.BAYER
-        if quality:
-            dither_type = DitherType.FLOYDSTEINBERG
-        subprocess.call(f'ffmpeg -i temp.mp4 -vf "split[s0][s1];[s0]palettegen[p];[s1][p]paletteuse=dither={dither_type.value}" -y {output}.gif', stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+
+        command = f'ffmpeg -i temp.mp4 -y {output}.gif'
+        if not low_quality:
+            command = f'ffmpeg -i temp.mp4 -vf "split[s0][s1];[s0]palettegen[p];[s1][p]paletteuse=dither=floyd_steinberg" -y "{output}.gif"'
+        subprocess.call(command, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+
         if shit_optimize:
             Utils.shit_optimize(output)
+
         os.remove("temp.mp4")
         return
 
     if not os.path.exists(filename):
         raise FileDoesNotExistError(f"File '{filename}' does not exist.")
 
-    reader, writer = __get_reader_writer(filename, output, width, fps_reduction, quality, dither, shit_optimize, text,
+    reader, writer = __get_reader_writer(filename, output, width, fps_reduction, low_quality, disable_dither, shit_optimize, text,
                                          text_style, progress_bar)
 
     try:
@@ -127,9 +130,6 @@ def gif2video(
         output: Optional[str] = None,
         width: Optional[int] = None,
         fps_reduction: int = 1,
-        quality: bool = False,
-        dither: bool = False,
-        shit_optimize: bool = False,
         text: str = "",
         text_style: TextStyle = TextStyle.TOP,
         progress_bar: bool = False
@@ -139,7 +139,7 @@ def gif2video(
     if filename[-4:] != ".gif":
         raise FileTypeError(f"File '{filename}' is not a gif.")
 
-    reader, writer = __get_reader_writer(filename, output, width, fps_reduction, quality, dither, shit_optimize, text,
+    reader, writer = __get_reader_writer(filename, output, width, fps_reduction, False, True, False, text,
                                          text_style, progress_bar)
 
     try:
